@@ -18,7 +18,9 @@ Functional test cases for the Barbican key manager.
 
 Note: This requires local running instances of Barbican and Keystone.
 """
+
 import abc
+import unittest
 
 from keystoneauth1 import identity
 from keystoneauth1 import session
@@ -26,7 +28,6 @@ from oslo_config import cfg
 from oslo_context import context
 from oslo_utils import uuidutils
 from oslotest import base
-from testtools import testcase
 
 from castellan.common.credentials import keystone_password
 from castellan.common.credentials import keystone_token
@@ -59,7 +60,7 @@ class BarbicanKeyManagerTestCase(test_key_manager.KeyManagerTestCase):
         except Exception as e:
             # When we run functional-vault target, This test class needs
             # to be skipped as barbican is not running
-            raise testcase.TestSkipped(str(e))
+            raise unittest.SkipTest(str(e))
 
     def tearDown(self):
         super(BarbicanKeyManagerTestCase, self).tearDown()
